<?php

namespace zaya;

use zaya\Core\View;
use zaya\Core\Request;
use zaya\Setup\Enqueue;
use zaya\Setup\AdminBar;
use zaya\Utilities\FlashMessages;
use zaya\Utilities\Meta;
use zaya\Setup\AdminPage;
use zaya\Setup\Metaboxes;
use zaya\Services\Config\Config;
use zaya\Custom\Columns\ShortLinkColumn;
use zaya\Custom\Shortcodes\ShortLinkShortcode;

class App
{
    private static $loaded = false;

    protected $request;

    public function __construct()
    {
        $this->request = new Request();
        $this->initClasses();
    }

    public function initClasses()
    {
        if (static::$loaded) {
            return;
        }
        static::$loaded = true;
        new FlashMessages;
        new AdminPage($this->request);
        new AdminBar();
        new Metaboxes($this->request);
        new ShortLinkColumn();
        new ShortLinkShortcode();
        if ($this->request->key_exists('page') && in_array($this->request->param('page'), [
                Config::get('app.links_slug'),
                Config::get('app.edit_slug'),
                Config::get('app.settings_slug'),
            ])) {
            new Enqueue();
        }
        if(get_option('zaya_show_in_posts') == 1) {
            add_filter('the_content', [&$this, 'the_content']);
        }
    }

    public function the_content($content)
    {
        $id = get_the_ID();
        if (! Meta::exists_shortlink($id) || ! in_array(get_post_type(), zayaPostTypes())) {
            return $content;
        }
        $data = json_decode(get_post_meta($id, Config::get('app.key_meta_box'), true), 512, JSON_UNESCAPED_UNICODE);
        $html = View::render('partials.box-short-link', compact('data'));

        return $content . $html;
    }
}