<?php

namespace zaya\Contracts;

use zaya\Core\Request;
use zaya\Services\Config\Config;
use zaya\Services\Translate\Trans;

if (! class_exists('WP_List_Table')) {
    require_once(ABSPATH . 'wp-admin/includes/class-wp-list-table.php');
}

abstract class BaseTable extends \WP_List_Table
{
    protected $data;

    protected $meta;

    protected $columns = [];

    protected $sortable_columns = [];

    protected $hide_columns = [];

    protected $block_actions = [];

    public function prepare_items()
    {
        $this->set_pagination_args([
            'total_items' => isset($this->meta->total) ? $this->meta->total : 0,
            'total_pages' => isset($this->meta->last_page) ? $this->meta->last_page : 0,
            'per_page' => isset($this->meta->per_page) ? $this->meta->per_page : 0,
        ]);
        $this->_column_headers = [
            $this->get_columns(),
            $this->hide_columns(),
            $this->get_sortable_columns(),
        ];
        $this->items = $this->data;
    }

    public function get_columns()
    {
        $columns = [];
        foreach ($this->columns as $key) {
            $columns[$key] = Trans::get('table.' . $key);
        }

        return $columns;
    }

    public function hide_columns()
    {
        return $this->hide_columns;
    }

    protected function get_sortable_columns()
    {
        return $this->sortable_columns;
    }

    protected function column_default($item, $column_name)
    {
        return $item->$column_name;
    }

    protected function get_bulk_actions()
    {
        $actions = [];
        foreach ($this->block_actions as $action) {
            $actions[$action] = Trans::get('table.' . $action);
        }

        return $actions;
    }

    abstract public function index(Request $request);
}