<?php

namespace zaya\Controllers;

use zaya\Core\Request;
use zaya\Services\Translate\Trans;
use zaya\Utilities\FlashMessages;
use zaya\Repositories\Links;
use zaya\Services\Config\Config;

class LinksControllers
{
    public function store(Request $request)
    {
        $data = $this->getData($request);
        $data = $this->validateData($data);
        $response = Links::getInstance()->store($data);
        $this->setMessage($response);
        Request::redirect(admin_url('admin.php?page=' . Config::get('app.links_slug')));
    }

    public function update(Request $request)
    {
        $data = $this->getData($request);
        $data = $this->validateData($data);
        $response = Links::getInstance()->update($request->param('id'), $data);
        $this->setMessage($response);
        Request::redirect(admin_url('admin.php?page=' . Config::get('app.links_slug')));
    }

    public function delete(Request $request)
    {
        $response = Links::getInstance()->delete($request->param('id'));
        $this->setMessage($response);
        Request::redirect(admin_url('admin.php?page=' . Config::get('app.links_slug')));
    }

    public function deleteItems(Request $request)
    {
        foreach ($_GET['ids'] as $id) {
            Links::getInstance()->delete($id);
        }

        return Request::redirect(admin_url('admin.php?page=' . Config::get('app.links_slug')));
    }

    public function disabledItems(Request $request)
    {
        foreach ($_GET['ids'] as $id) {
            Links::getInstance()->update($id, ['disabled' => 1]);
        }

        return Request::redirect(admin_url('admin.php?page=' . Config::get('app.links_slug')));
    }

    private function getData(Request $request)
    {
        return [
            'url' => $request->param('url'),
            'alias' => $request->param('alias'),
            'domain' => is_numeric($request->param('domain')) ? intval($request->param('domain')) : '',
            'expiration_url' => $request->param('expiration_url') != 'http://' ? $request->param('expiration_url') : '',
            'password' => $request->param('password'),
            'expiration_clicks' => $request->param('expiration_clicks'),
            'expiration_date' => ! $request->key_empty('expiration_date') ? date('Y-m-d', $request->param('expiration_date')) : null,
            'expiration_time' => ! $request->key_empty('expiration_date') ? $request->param('expiration_time') : '',
            'disabled' => $request->param('status'),
            'public' => $request->param('is_public'),
            'space' => get_option(Config::get('app.others_space_key')),
        ];
    }

    private function validateData($data)
    {
        foreach ($data as $key => $item) {
            if (! empty($item) || $item == 0) {
                continue;
            }
            unset($data[$key]);
        }

        return $data;
    }

    /**
     * @param $response
     */
    private function setMessage($response)
    {
        if ($response->status == 200) {
            FlashMessages::queue_flash_message(Trans::get('table.success'), 'notice-success');
        }
    }
}