<?php

namespace zaya\Controllers;

use zaya\Core\View;
use zaya\Core\Request;
use zaya\Utilities\Auth;
use zaya\Utilities\Meta;
use zaya\Utilities\Metabox;
use zaya\Repositories\Links;
use zaya\Services\Config\Config;

class MetaboxController
{
    public function create()
    {
        $post_types = zayaPostTypes();
        if (! Auth::isLoggedIn() || empty($post_types) || ! in_array(get_post_type(), $post_types)) {
            return;
        }
        if (get_post_status(get_the_ID()) != 'publish') {
            return View::load('disabled-meta-box');
        }
        if (! Meta::exists_shortlink(get_the_ID())) {
            return View::load('not-exists');
        }

        return View::load('meta-box', ['post_id' => get_the_ID()]);
    }

    public function save($post_id, Request $request)
    {
        $post_types = zayaPostTypes();
        if ((defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) || ! Auth::isLoggedIn() || empty($post_types) || ! in_array(get_post_type(), $post_types)) {
            return;
        }
        if (get_post_status($post_id) != 'publish') {
            return;
        }

        if (get_post_status($post_id) == 'publish' && ! Meta::exists_shortlink($post_id)) {
            $response = Metabox::create(get_the_permalink($post_id));

            return Meta::update_shortlink($response, $post_id);
        }

        if ($request->key_exists('zaya_new_alias') && ! $request->key_empty('zaya_new_alias')) {
            $response = Metabox::update($request->param('zaya_sort_link_id'), get_the_permalink($post_id), $request->param('zaya_new_alias'),
                $request->param('zaya_domain'));
            Meta::update_shortlink($response, $post_id);
        }

        /*if ($this->is_default_domain_changed()) {
            Links::getInstance()->delete($request->param('zaya_sort_link_id'));
            $response = Metabox::create(get_the_permalink($post_id));

            return Meta::update_shortlink($response, $post_id);
        }*/
    }

    private function is_default_domain_changed()
    {
        $url = get_post_meta(get_the_ID(), 'zaya_short_link', true);
        $default_domain = get_option(Config::get('app.default_domain_url_key_option'));

        return strpos($url, $default_domain) === false;
    }
}