<?php

namespace zaya\Controllers;

use zaya\Core\Request;
use zaya\Utilities\FlashMessages;
use zaya\Utilities\Space;
use zaya\Repositories\Spaces;
use zaya\Repositories\Domains;
use zaya\Services\Config\Config;
use zaya\Services\Translate\Trans;

class SettingControllers
{
    public function update(Request $request)
    {
        update_option(Config::get('app.token_key_option'), $request->param(Config::get('app.token_key_option')));
        $this->login($request);
        $this->setDefaultDomain($request);
        update_option('zaya_post_types', $request->param('zaya_post_types'));
        $show_in_posts = $request->key_exists('show_in_posts') && $request->param('show_in_posts') ? 1 : 0;
        update_option('zaya_show_in_posts', $show_in_posts);
        FlashMessages::queue_flash_message(Trans::get('table.success'), 'notice-success');

        return Request::redirect($request->referer);
    }

    private function login(Request $request)
    {
        $response = Spaces::getInstance()->all();
        if (isset($response->message)) {
            FlashMessages::queue_flash_message(Trans::get('settings.login_failed'), 'notice-failed');
            delete_option(Config::get('app.token_key_option'));

            return Request::redirect($request->referer);
        }
        if (! Space::existsDefaultSpace()) {
            return Space::createDefaultSpace();
        }
    }

    private function setDefaultDomain(Request $request)
    {
        $id = $request->param('zaya_default_domain');
        if (! empty($id)) {
            if (! in_array($id, array_keys(Config::get('app.default_domains')))) {
                $domain = Domains::getInstance()->detail($id);
                update_option('zaya_default_domain', $id);
                update_option(Config::get('app.default_domain_url_key_option'), $domain->data->name);

                return;
            }
            update_option('zaya_default_domain', $id);
            update_option(Config::get('app.default_domain_url_key_option'), Config::get('app.default_domains')[$id]);

            return;
        }

        delete_option('zaya_default_domain');
        update_option(Config::get('app.default_domain_url_key_option'), 'https://zaya.io');
    }
}