<?php

namespace zaya\Core;

use zaya\Utilities\Input;

class Request
{
    public $method;

    public $uri;

    public $ip;

    public $agent;

    public $referer;

    public $params;     // $_REQUEST

    public $files;

    private $prefixUri = ZAYA_NAME;

    public function __construct()
    {
        if (SANITIZE_ALL_DATA) {
            $this->params = Input::clean($_REQUEST);
        } else {
            $this->params = $_REQUEST;
        }
        $this->files = $_FILES;
        $this->method = strtolower($_SERVER['REQUEST_METHOD']);
        $this->uri = $_SERVER['REQUEST_URI'];
        $this->ip = $_SERVER['REMOTE_ADDR'];
        $this->agent = $_SERVER['HTTP_USER_AGENT'];
        $this->referer = isset($_SERVER['HTTP_REFERER']) ? $_SERVER['HTTP_REFERER'] : '';
    }

    public function key_exists($key)
    {
        return in_array($key, array_keys($this->params));
    }

    public function key_empty($key)
    {
        return ! in_array($key, array_keys($this->params)) || empty($this->param($key));
    }

    public function isAjax()
    {
        return ! empty($_SERVER['HTTP_X_REQUESTED_WITH']) && strtolower($_SERVER['HTTP_X_REQUESTED_WITH']) == 'xmlhttprequest';
    }

    public function isPost()
    {
        return $this->method === 'post';
    }

    public function isGet()
    {
        return $this->method === 'get';
    }

    public function prefixUriExists()
    {
        $parts = explode('/', $this->uri);

        return in_array($this->prefixUri, $parts);
    }

    public function isValidRequest()
    {
        return $this->prefixUriExists() && ($this->isPost() || $this->isAjax());
    }

    public function param($key)
    {
        return $this->params[$key];
    }

    public static function redirect($address)
    {
        if (filter_var($address, FILTER_VALIDATE_URL)) {
            header("Location: " . $address);
            die();
        }
        header("Location: " . get_site_url($address));
        die();
    }

    public static function jsRedirect($address, $secs)
    {
        $secs = ($secs * 1000);
        echo "<script>setTimeout(function(){window.location.href = '" . $address . "';}, $secs);</script>";
        die();
    }

    public function __get($key)
    {
        if ($this->key_exists($key)) {
            return $this->{$key} = $this->param($key);
        } else {
            if (IS_DEV_MODE) {
                throw new \Exception($key . ' not exists.');
            }

            return header("HTTP/1.1 500 Internal Server Error");
        }
    }
}