<?php

namespace zaya\Custom\Pages;

use zaya\Core\View;
use zaya\Core\Request;
use zaya\Utilities\Embed;
use zaya\Utilities\Space;
use zaya\Contracts\BaseTable;
use zaya\Repositories\Spaces;
use zaya\Services\Config\Config;
use zaya\Services\Translate\Trans;

class Links extends BaseTable
{
    protected $columns = [
        'cb',
        'title',
        'clicks',
        'alias',
        'short_url',
        'disabled',
        'created_at',
    ];

    protected $block_actions = [
        'deleteItems',
    ];

    public function index(Request $request)
    {
        $paged = $request->key_exists('paged') ? intval($request->param('paged')) : 1;
        $search = $request->key_exists('s') ? $request->param('s') : null;
        $space = $request->key_exists('space') ? $request->param('space') : get_option(Config::get('app.others_space_key'));
        $all = \zaya\Repositories\Links::getInstance()->all($paged, $space, $search);
        $this->data = isset($all->data) ? $all->data : null;
        $this->meta = isset($all->meta) ? $all->meta : null;
        $this->prepare_items();
        $embed = Embed::get();

        return View::load('links', [
            'table' => $this,
            'title' => zayaTrans('menu.custom_links_page'),
            'embed' => $embed,
        ]);
    }

    public function column_title($item)
    {
        $actions = [
            'edit' => '<a href="' . add_query_arg([
                    'page' => Config::get('app.edit_slug'),
                    'id' => $item->id,
                ]) . '">' . zayaTrans('table.edit') . '</a>',
            'delete' => '<a href="' . add_query_arg([
                    'action' => 'delete',
                    'id' => $item->id,
                ]) . '">' . zayaTrans('table.delete') . '</a>',
        ];
        $title = "<a title='$item->url' href='$item->url' target='_blank'>$item->title</a>";

        return $title . ' ' . $this->row_actions($actions);
    }

    public function column_disabled($item)
    {
        switch ($item->status) {
            case 1 :
                return zayaTrans('table.active');
            case 2 :
                return zayaTrans('table.pending');
            case 3 :
                return zayaTrans('table.deactivate');
            case 4 :
                return zayaTrans('table.suspended');
            case 5 :
                return zayaTrans('table.expired');
        }
        return $item->status == 0 ? zayaTrans('table.deactivate') : zayaTrans('table.active');
    }

    public function column_created_at($item)
    {
        return human_time_diff(strtotime($item->created_at)) . ' ' . Trans::get('table.ago');
    }

    public function column_short_url($item)
    {
        $output = '<script>function copy_clipboard(elm) {
                  let copyText = elm.nextElementSibling;
                  copyText.select();
                  copyText.setSelectionRange(0, 99999)
                  document.execCommand("copy");
            }</script>';
        $clipboard = '<span style="background-color:#aaa;font-size: 8px;color: #fff;padding: 5px;border-radius: 4px;' . 'margin-left: 10px;cursor: pointer" id="copy_clipboard" onClick="copy_clipboard(this)">Copy</span>';
        $output .= $clipboard . '<input style="border:0;background-color:transparent;outline:0" value="' . $item->short_url . '">';

        return $output;
    }

    protected function column_cb($item)
    {
        return sprintf('<input type="checkbox" name="ids[]" value="%s" />', $item->id);
    }

    protected function extra_tablenav($which)
    {
        if ($which !== 'top') {
            return;
        }
        $spaces = isset(Spaces::getInstance()->all()->data) ? Spaces::getInstance()->all()->data : null;

        return View::load('tablenav-filter', compact('spaces'));
    }
}