<?php

namespace zaya\Services\Curl;

use zaya\Utilities\Auth;
use zaya\Utilities\FlashMessages;
use zaya\Services\Config\Config;
use zaya\Services\Translate\Trans;

class Curl
{
    private $token;

    private $curl;

    public function __construct()
    {
        $this->curl = new \Curl\Curl();
        $this->token = get_option(Config::get('app.token_key_option'));
    }

    public function getResponse()
    {
        return $this->curl->response;
    }

    public function getRequestHeaders()
    {
        return $this->curl->getRequestHeaders();
    }

    public function existsError()
    {
        return $this->curl->error;
    }

    public function getErrorCode()
    {
        return $this->curl->errorCode;
    }

    public function getErrorMessage()
    {
        return $this->curl->errorMessage;
    }

    public function loginWithToken()
    {
        if (! Auth::isLoggedIn()) {
            FlashMessages::queue_flash_message(Trans::get('settings.not_login'), 'notice-failed');
            return false;
        }
        $this->setHeader('Authorization', "Bearer $this->token");

        return $this;
    }

    public function setJsonType()
    {
        $this->setHeader('Accept', 'application/json');

        return $this;
    }

    public function setContentType()
    {
        $this->setHeader('Content-Type', 'application/x-www-form-urlencoded');

        return $this;
    }

    public function get($uri, $data = [])
    {
        return $this->curl->get($uri, $data);
    }

    public function post($url, $data = '', $follow_303_with_post = false)
    {
        return $this->curl->post($url, $data, $follow_303_with_post);
    }

    public function setHeader($key, $value)
    {
        return $this->curl->setHeader($key, $value);
    }

    public function setHeaders($headers)
    {
        return $this->curl->setHeaders($headers);
    }

    public function put($url, $data = array())
    {
        return $this->curl->put($url, $data);
    }

    public function delete($url, $query_parameters = [], $data = [])
    {
        return $this->curl->delete($url, $query_parameters, $data);
    }
}