<?php

namespace zaya\Setup;

use zaya\Core\View;
use zaya\Core\Request;
use zaya\Custom\Pages\AddLink;
use zaya\Services\Config\Config;
use zaya\Controllers\LinksControllers;
use zaya\Custom\Pages\Settings;
use zaya\Custom\Pages\Links;
use zaya\Controllers\SettingControllers;

class AdminPage
{
    private $request;

    public function __construct(Request $request)
    {
        $this->request = $request;
        add_action('admin_menu', [
            &$this,
            'add_admin_page',
        ]);
    }

    public function add_admin_page()
    {
        $this->primary();
        $this->links();
        $this->edit();
        $this->settings();
    }

    private function primary()
    {
        $page = add_menu_page(zayaTrans('menu.title'), zayaTrans('menu.menu'),
            Config::get('app.permission_access'), Config::get('app.links_slug'), function () {
                return (new Links())->index($this->request);
            }, PLUGIN_ICON);

        if (! $page) {
            return;
        }

        if ($this->request->isPost()) {
            add_action("load-$page", function () {
                return (new LinksControllers())->store($this->request);
            });
        }
        if ($this->isRequestDelete()) {
            add_action("load-$page", function () {
                return (new LinksControllers())->delete($this->request);
            });
        }
        if ($this->isRequestDeleteItems()) {
            add_action("load-$page", function () {
                return (new LinksControllers())->deleteItems($this->request);
            });
        }
    }

    private function links()
    {
        add_submenu_page(Config::get('app.links_slug'), zayaTrans('menu.custom_links_page'),
            zayaTrans('menu.custom_links_menu'), Config::get('app.permission_access'), Config::get('app.links_slug'));
    }

    private function edit()
    {
        $edit = add_submenu_page(null, zayaTrans('menu.edit_page'), zayaTrans('menu.edit_menu'),
            Config::get('app.permission_access'), Config::get('app.edit_slug'), function () {
                $data = \zaya\Repositories\Links::getInstance()->detail($this->request->param('id'))->data;

                return View::load('edit-link', compact('data'));
            });
        if ($edit && $this->request->isPost()) {
            add_action("load-$edit", function () {
                return (new LinksControllers())->update($this->request);
            });
        }
    }

    private function settings()
    {
        $settings = add_submenu_page(Config::get('app.links_slug'), zayaTrans('menu.settings_page'),
            zayaTrans('menu.settings_menu'), Config::get('app.permission_access'), Config::get('app.settings_slug'), function () {
                return (new Settings())->index($this->request);
            });
        if ($settings && $this->request->isPost()) {
            add_action("load-$settings", function () {
                return (new SettingControllers())->update($this->request);
            });
        }
    }

    private function isRequestDelete()
    {
        return $this->request->key_exists('action') && $this->request->param('action') == 'delete' && ! $this->request->key_empty('id');
    }

    private function isRequestDeleteItems()
    {
        return $this->request->key_exists('action') && $this->request->param('action') == 'deleteItems';
    }
}